-- ----------------------------
-- 区域天气实况表
-- ----------------------------
DROP TABLE IF EXISTS `adm_area_weather_rt`;
CREATE TABLE `adm_area_weather_rt` (
    `adcode`          varchar(16)  NOT NULL COMMENT '行政区划编码',
    `area_name`       varchar(32)  NOT NULL COMMENT '区域名称',
    `date`            date         NOT NULL COMMENT '日期',
    `weather_type`    varchar(8)   NOT NULL COMMENT '天气代码',
    `weather_cn`      varchar(128) DEFAULT NULL COMMENT '天气描述',
    `temperature`     double       DEFAULT NULL COMMENT '温度',
    `humidity`        int          DEFAULT NULL COMMENT '湿度',
    `wind_power`      varchar(8)   DEFAULT NULL COMMENT '风力级别',
    `wind_direction`  varchar(64)  DEFAULT NULL COMMENT '风向',
    `report_time`     datetime     DEFAULT NULL COMMENT '数据时间',
    `create_time`     datetime     DEFAULT CURRENT_TIMESTAMP    comment '创建时间',
    PRIMARY KEY (`adcode`,`date`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='区域天气实况';


-- ----------------------------
-- 区域天气预报
-- ----------------------------
DROP TABLE IF EXISTS `adm_area_weather_forecast`;
CREATE TABLE `adm_area_weather_forecast` (
    `adcode`              varchar(16)    NOT NULL COMMENT '行政区划编码',
    `area_name`           varchar(32)    NOT NULL COMMENT '区域名称',
    `date`                date           NOT NULL COMMENT '日期',
    `day_weather_type`    varchar(8)     DEFAULT NULL COMMENT '日间天气代码',
    `day_weather_cn`      varchar(128)   DEFAULT NULL COMMENT '日间天气描述',
    `night_weather_type`  varchar(8)     DEFAULT NULL COMMENT '夜间天气代码',
    `night_weather_cn`    varchar(128)   DEFAULT NULL COMMENT '夜间天气描述',
    `day_temp`            double         DEFAULT NULL COMMENT '日间气温',
    `night_temp`          double         DEFAULT NULL COMMENT '夜间气温',
    `day_wind_power`      varchar(8)     DEFAULT NULL COMMENT '日间风力',
    `night_wind_power`    varchar(8)     DEFAULT NULL COMMENT '夜间风力',
    `day_wind_dir`        varchar(64)    DEFAULT NULL COMMENT '日间风向',
    `night_wind_dir`      varchar(64)    DEFAULT NULL COMMENT '夜间风向',
    `report_time`         datetime       DEFAULT NULL COMMENT '数据时间',
    `create_time`         datetime       DEFAULT CURRENT_TIMESTAMP    comment '创建时间',
    PRIMARY KEY (`adcode`,`date`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='区域天气预报';


-- ----------------------------
-- 节假日
-- ----------------------------
DROP TABLE IF EXISTS `adm_holiday`;
CREATE TABLE `adm_holiday` (
    `date`    date NOT NULL COMMENT '日期',
    `name`    VARCHAR(128) NOT NULL COMMENT '节假日',
    `name_cn` VARCHAR(128) NOT NULL COMMENT '节假日中文',
    `name_en` VARCHAR(128) NOT NULL COMMENT '节假日英文',
    `type`    VARCHAR(64) NOT NULL COMMENT '节假日类型',
    PRIMARY KEY (`date`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='节假日信息表';


-- ----------------------------
-- 接口认证
-- ----------------------------
DROP TABLE IF EXISTS `adm_api_auth`;
CREATE TABLE `adm_api_auth` (
    `id` INT(11) NOT NULL AUTO_INCREMENT,
    `client_id` VARCHAR(64) NOT NULL COMMENT '客户端ID',
    `client_name` VARCHAR(128) NOT NULL COMMENT '客户端名称',
    `api_key` VARCHAR(64) NOT NULL COMMENT 'API密钥',
    `status` TINYINT(1) NOT NULL DEFAULT '1' COMMENT '状态 1-有效 0-禁用',
    `expire_time` DATETIME DEFAULT NULL COMMENT '过期时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `uniq_client` (`client_id`),
    KEY `idx_apikey` (`api_key`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Api认证信息表';