package com.ruoyi.web.controller.ems;

import com.huashe.common.domain.AjaxResult;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.ems.domain.FacsCategory;
import com.ruoyi.ems.service.IFacsCategoryService;
import io.swagger.annotations.Api;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 能源设施/系统类别Controller
 *
 * @author ruoyi
 * @date 2024-07-11
 */
@RestController
@RequestMapping("/ems/basecfg/facsCategory")
@Api(value = "FacsCategoryController", description = "设施类别管理")
public class FacsCategoryController extends BaseController {
    @Autowired
    private IFacsCategoryService facsCategoryService;

    /**
     * 查询能源设施/系统分类列表
     */
    @PreAuthorize("@ss.hasPermi('basecfg:facscategory:list')")
    @GetMapping("/list")
    public TableDataInfo list(FacsCategory category) {
        startPage();
        List<FacsCategory> list = facsCategoryService.selectCategoryList(category);
        return getDataTable(list);
    }

    /**
     * 获取所有能源设施/系统分类
     *
     * @return 能源设施/系统分类列表
     */
    @GetMapping("/listall")
    public AjaxResult listAll() {
        List<FacsCategory> list = facsCategoryService.selectCategoryList(new FacsCategory());
        return success(list);
    }

    /**
     * 导出能源设施/系统分类列表
     */
    @PreAuthorize("@ss.hasPermi('basecfg:facscategory:export')")
    @Log(title = "能源设施/系统分类", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, FacsCategory category) {
        List<FacsCategory> list = facsCategoryService.selectCategoryList(category);
        ExcelUtil<FacsCategory> util = new ExcelUtil<FacsCategory>(FacsCategory.class);
        util.exportExcel(response, list, "能源设施/系统分类数据");
    }

    /**
     * 获取能源设施/系统分类详细信息
     */
    @PreAuthorize("@ss.hasPermi('basecfg:facscategory:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(facsCategoryService.selectCategoryById(id));
    }

    /**
     * 获取能源设施/系统分类详细信息
     */
    @PreAuthorize("@ss.hasPermi('basecfg:facscategory:query')")
    @GetMapping(value = "/getByCode")
    public AjaxResult getByCode(@RequestParam(name = "code") String code) {
        return success(facsCategoryService.selectCategoryByCode(code));
    }

    /**
     * 新增能源设施/系统分类
     */
    @PreAuthorize("@ss.hasPermi('basecfg:facscategory:add')")
    @Log(title = "能源设施/系统分类", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody FacsCategory category) {
        return toAjax(facsCategoryService.insertCategory(category));
    }

    /**
     * 修改能源设施/系统分类
     */
    @PreAuthorize("@ss.hasPermi('basecfg:facscategory:edit')")
    @Log(title = "能源设施/系统分类", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody FacsCategory category) {
        return toAjax(facsCategoryService.updateCategory(category));
    }

    /**
     * 删除能源设施/系统分类
     */
    @PreAuthorize("@ss.hasPermi('basecfg:facscategory:remove')")
    @Log(title = "能源设施/系统分类", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(facsCategoryService.deleteCategoryByIds(ids));
    }
}
