package com.ruoyi.ems.controller;

import java.util.List;

import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.huashe.common.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.page.TableDataInfo;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.ems.domain.CaMeterD;
import com.ruoyi.ems.service.ICaMeterDService;

import io.swagger.annotations.Api;

/**
 * 碳计量日Controller
 *
 * @author ruoyi
 * @date 2024-08-12
 */
@RestController
@RequestMapping("/caMeterD")
@Api(value = "CaMeterDController", description = "碳计量日数据访问接口")
public class CaMeterDController extends BaseController {
    @Autowired
    private ICaMeterDService caMeterDService;

    /**
     * 查询碳计量日列表
     */
    @RequiresPermissions("ca-analysis:emission:list")
    @GetMapping("/list")
    public TableDataInfo list(CaMeterD caMeterD) {
        startPage();
        List<CaMeterD> list = caMeterDService.selectCaMeterDList(caMeterD);
        return getDataTable(list);
    }

    @RequiresPermissions("ca-analysis:emission:list")
    @GetMapping("/list/all")
    public AjaxResult listAll(CaMeterD caMeterD) {
        List<CaMeterD> list = caMeterDService.selectSumCaMeterDList(caMeterD);
        return success(list);
    }

    /**
     * 导出碳计量日列表
     */
    @RequiresPermissions("ca-analysis:emission:export")
    @Log(title = "碳计量日", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CaMeterD caMeterD) {
        List<CaMeterD> list = caMeterDService.selectCaMeterDList(caMeterD);
        ExcelUtil<CaMeterD> util = new ExcelUtil<CaMeterD>(CaMeterD.class);
        util.exportExcel(response, list, "碳计量日数据");
    }

    /**
     * 获取碳计量日详细信息
     */
    @RequiresPermissions("ca-analysis:emission:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(caMeterDService.selectCaMeterDById(id));
    }

    /**
     * 新增碳计量日
     */
    @RequiresPermissions("ca-analysis:emission:add")
    @Log(title = "碳计量日", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CaMeterD caMeterD) {
        return toAjax(caMeterDService.insertCaMeterD(caMeterD));
    }

    /**
     * 修改碳计量日
     */
    @RequiresPermissions("ca-analysis:emission:edit")
    @Log(title = "碳计量日", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CaMeterD caMeterD) {
        return toAjax(caMeterDService.updateCaMeterD(caMeterD));
    }

    /**
     * 删除碳计量日
     */
    @RequiresPermissions("ca-analysis:emission:remove")
    @Log(title = "碳计量日", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(caMeterDService.deleteCaMeterDByIds(ids));
    }
}
