package com.ruoyi.ems.controller;

import com.huashe.common.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.page.TableDataInfo;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.ems.domain.ElecConsumeForecast;
import com.ruoyi.ems.service.IElecConsumeForecastService;
import io.swagger.annotations.Api;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 电力消耗预测Controller
 *
 * @author ruoyi
 * @date 2024-08-12
 */
@RestController
@RequestMapping("/forecastConsume")
@Api(value = "ElecExpendForecastController", description = "电力消耗预测数据访问接口")
public class ElecConsumeForecastController extends BaseController {
    @Autowired
    private IElecConsumeForecastService forecastService;

    /**
     * 查询电力消耗预测列表
     */
    @RequiresPermissions("prediction:consume:list")
    @GetMapping("/list")
    public TableDataInfo list(ElecConsumeForecast forecast) {
        startPage();
        List<ElecConsumeForecast> list = forecastService.selectForecastList(forecast);
        return getDataTable(list);
    }

    /**
     * 导出电力消耗预测列表
     */
    @RequiresPermissions("prediction:consume:export")
    @Log(title = "电力消耗预测", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ElecConsumeForecast elecExpendForecast) {
        List<ElecConsumeForecast> list = forecastService.selectForecastList(elecExpendForecast);
        ExcelUtil<ElecConsumeForecast> util = new ExcelUtil<ElecConsumeForecast>(ElecConsumeForecast.class);
        util.exportExcel(response, list, "电力消耗预测数据");
    }

    /**
     * 获取电力消耗预测详细信息
     */
    @RequiresPermissions("prediction:consume:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(forecastService.selectForecastById(id));
    }

    /**
     * 新增电力消耗预测
     */
    @RequiresPermissions("prediction:consume:add")
    @Log(title = "电力消耗预测", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ElecConsumeForecast elecExpendForecast) {
        return toAjax(forecastService.insertForecast(elecExpendForecast));
    }

    /**
     * 修改电力消耗预测
     */
    @RequiresPermissions("prediction:consume:edit")
    @Log(title = "电力消耗预测", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ElecConsumeForecast elecExpendForecast) {
        return toAjax(forecastService.updateForecast(elecExpendForecast));
    }

    /**
     * 删除电力消耗预测
     */
    @RequiresPermissions("prediction:consume:remove")
    @Log(title = "电力消耗预测", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(forecastService.deleteForecastByIds(ids));
    }

    @GetMapping(value = "/cal/dateRange")
    public AjaxResult calcElecExpendForecastDateRange(ElecConsumeForecast param) {
        return success(forecastService.calcForecastDateRange(param));
    }
}
