package com.ruoyi.ems.controller;

import com.huashe.common.domain.AjaxResult;
import com.huashe.common.exception.BusinessException;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.page.TableDataInfo;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.ems.domain.ElecPvSupplyH;
import com.ruoyi.ems.model.QueryMeter;
import com.ruoyi.ems.service.IElecPvSupplyHService;
import io.swagger.annotations.Api;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.time.format.DateTimeParseException;
import java.util.List;

/**
 * 光伏并网计量-小时Controller
 *
 * @author ruoyi
 * @date 2024-08-02
 */
@RestController
@RequestMapping("/prod/pv")
@Api(value = "ElecPvSupplyHController", description = "光伏并网计量数据接口")
public class ElecPvSupplyHController extends BaseController {
    @Autowired
    private IElecPvSupplyHService pvSupplyHService;

    /**
     * 查询光伏并网计量光伏并网计量-小时列表
     */
    @RequiresPermissions("ems:prod:list")
    @GetMapping("/hour/list")
    public TableDataInfo list(ElecPvSupplyH pvSupplyH) {
        startPage();
        List<ElecPvSupplyH> list = pvSupplyHService.selectPvSupplyHList(pvSupplyH);
        return getDataTable(list);
    }

    /**
     * 查询光伏并网计量光伏并网计量-小时列表
     */
    @RequiresPermissions("ems:prod:list")
    @GetMapping("/day/list")
    public AjaxResult listByDay(QueryMeter queryMeter) {
        List<ElecPvSupplyH> list = pvSupplyHService.selectPvSupplyDayList(queryMeter);
        return success(list);
    }

    /**
     * 导出光伏并网计量光伏并网计量-小时列表
     */
    @Log(title = "光伏并网计量光伏并网计量-小时", businessType = BusinessType.EXPORT)
    @PostMapping("/hour/export")
    public void export(HttpServletResponse response, ElecPvSupplyH pvSupplyH) throws IOException {
        try {
            validateTimeRange(pvSupplyH);

            List<ElecPvSupplyH> list = pvSupplyHService.selectPvSupplyHList(pvSupplyH);
            ExcelUtil<ElecPvSupplyH> util = new ExcelUtil<ElecPvSupplyH>(ElecPvSupplyH.class);
            util.exportExcel(response, list, "光伏并网计量光伏并网计量-小时数据");
        } catch (BusinessException e) {
            // 统一异常处理
            handleExportException(response, e);
        } catch (DateTimeParseException e) {
            handleExportException(response, new BusinessException("时间格式错误，请使用yyyy-MM-dd HH:mm:ss格式"));
        }
    }

    /**
     * 校验时间范围有效性（精确到秒）
     */
    private void validateTimeRange(ElecPvSupplyH pvSupplyH) {
        // 参数校验
        if (pvSupplyH.getStartRecTime() == null || pvSupplyH.getEndRecTime() == null) {
            throw new BusinessException("开始时间和结束时间必须同时填写");
        }

        // 日期时间格式化器
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");

        try {
            // 解析日期时间
            LocalDateTime startDateTime = LocalDateTime.parse(pvSupplyH.getStartRecTime(), formatter);
            LocalDateTime endDateTime = LocalDateTime.parse(pvSupplyH.getEndRecTime(), formatter);

            // 校验时间顺序
            if (endDateTime.isBefore(startDateTime)) {
                throw new BusinessException("结束时间不能早于开始时间");
            }

            // 计算最大允许结束时间（精确到秒）
            LocalDateTime maxEndDateTime = startDateTime.plusDays(90).minusSeconds(1);

            // 校验时间范围（90天范围）
            if (endDateTime.isAfter(maxEndDateTime)) {
                throw new BusinessException("时间范围不能超过90天（最大允许到：" +
                    maxEndDateTime.format(formatter) + "）");
            }

        } catch (DateTimeParseException e) {
            throw new BusinessException("时间格式错误，请使用yyyy-MM-dd HH:mm:ss格式");
        }
    }

    /**
     * 统一异常处理
     */
    private void handleExportException(HttpServletResponse response, BusinessException e) {
        response.reset();
        response.setContentType("application/json");
        response.setCharacterEncoding("utf-8");
        try {
            response.getWriter().print("{\"code\":400,\"msg\":\"" + e.getMessage() + "\"}");
        }
        catch (IOException ex) {
            // 记录日志等处理
        }
    }
}
