package com.ruoyi.ems.mapper;

import com.ruoyi.ems.domain.ElecPvSupplyH;
import com.ruoyi.ems.domain.EnergyMeter;
import com.ruoyi.ems.domain.ElecMeterH;
import com.ruoyi.ems.model.QueryMeter;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 用电计量-小时Mapper接口
 *
 * @author ruoyi
 * @date 2024-12-03
 */
public interface ElecMeterHMapper {
    /**
     * 查询用电计量-小时列表
     *
     * @param queryMeter 查询计量条件
     * @return 用电计量-小时集合
     */
    List<ElecMeterH> selectElecMeterByDev(QueryMeter queryMeter);

    /**
     * 查询用电计量-小时列表
     *
     * @param queryMeter 查询计量条件
     * @return 用电计量-小时集合
     */
    List<ElecMeterH> selectElecMeterByDevs(QueryMeter queryMeter);

    /**
     * 查询用电计量-日汇总列表
     *
     * @param queryMeter 查询计量条件
     * @return 用电计量-日集合
     */
    List<ElecMeterH> selectElecMeterDayList(QueryMeter queryMeter);

    /**
     * 查询最近一条计量
     *
     * @param deviceCode 设备编码
     * @return 用电计量
     */
    ElecMeterH selectLatelyItem(@Param("deviceCode") String deviceCode);

    /**
     * 查询用电计量-小时列表
     *
     * @param queryMeter 查询计量条件
     * @return 用电计量-小时集合
     */
    EnergyMeter selectElecMeterSumByDev(QueryMeter queryMeter);

    /**
     * 查询日用电平均
     *
     * @param queryMeter 查询计量条件
     * @return 用电计量-小时集合
     */
    EnergyMeter selectElecDayAvg(QueryMeter queryMeter);

    /**
     * 根据时间统计
     *
     * @param queryMeter 查询条件
     * @return 统计
     */
    List<EnergyMeter> selectStaByTime(QueryMeter queryMeter);

    /**
     * 新增用电计量-小时
     *
     * @param elecMeterH 用电计量-小时
     * @return 结果
     */
    int insertElecMeterH(ElecMeterH elecMeterH);

    /**
     * 新增用电计量-小时
     *
     * @param list 用电计量-小时
     * @return 结果
     */
    int insertBatch(List<ElecMeterH> list);

    /**
     * 修改用电计量-小时
     *
     * @param elecMeterH 用电计量-小时
     * @return 结果
     */
    int updateElecMeterH(ElecMeterH elecMeterH);

    /**
     * 删除用电计量（根据日期）
     *
     * @param date 日期
     * @return 结果
     */
    int deleteElecMeterHByDate(@Param("date") String date);


    EnergyMeter qryElecMeterByDate(ElecMeterH dataRange);

    List<ElecMeterH> qryTimeIndexElecMeterByDay(@Param("dataRange") String dataRange);

    List<ElecMeterH> qryDateElecMeterByDate(String dataRange);

    List<ElecMeterH> qryDateElecMeterByYear(String dataRange);

    List<ElecMeterH> qryDeviceTypeElecMeterByDay(ElecMeterH elecMeterH);

}
