package com.ruoyi.ems.service;

import com.ruoyi.ems.domain.EmsDevice;
import com.ruoyi.ems.model.QueryDevice;

import java.util.List;
import java.util.Map;

/**
 * 能源设备Service接口
 *
 * @author ruoyi
 * @date 2024-07-10
 */
public interface IEmsDeviceService {
    /**
     * 查询能源设备
     *
     * @param id 能源设备主键
     * @return 能源设备
     */
    EmsDevice selectEmsDeviceById(Long id);

    /**
     * 查询能源设备
     *
     * @param code 设备编码
     * @return 能源设备
     */
    EmsDevice selectByCode(String code);

    /**
     * 查询能源设备
     *
     * @param code 设备编码
     * @return 能源设备
     */
    EmsDevice selectDetailByCode(String code);

    /**
     * 查询能源设备列表
     *
     * @param queryDevice 能源设备
     * @return 能源设备集合
     */
    List<EmsDevice> selectList(QueryDevice queryDevice);

    /**
     * 查询能源设备列表
     *
     * @param queryDevice 能源设备
     * @return 能源设备集合
     */
    List<EmsDevice> selectDetailList(QueryDevice queryDevice);

    /**
     * 查询能源设备列表
     *
     * @param queryDevice 查询参数
     * @return 能源设备集合
     */
    List<EmsDevice> selectByAreaTree(QueryDevice queryDevice);

    /**
     * 查询能源设备列表
     *
     * @param emsDevice 能源设备
     * @return 能源设备集合
     */
    List<EmsDevice> selectByFlowRel(QueryDevice emsDevice);

    /**
     * 新增能源设备
     *
     * @param emsDevice 能源设备
     * @return 结果
     */
    int insertEmsDevice(EmsDevice emsDevice);

    /**
     * 修改能源设备
     *
     * @param emsDevice 能源设备
     * @return 结果
     */
    int updateEmsDevice(EmsDevice emsDevice);

    /**
     * 批量删除能源设备
     *
     * @param ids 需要删除的能源设备主键集合
     * @return 结果
     */
    int deleteEmsDeviceByIds(Long[] ids);

    /**
     * 删除能源设备信息
     *
     * @param id 能源设备主键
     * @return 结果
     */
    int deleteEmsDeviceById(Long id);

    List<Map<String, Object>> cntDeviceStatus(String areaCode);

    List<Map<String, Object>> calcDeviceOnlineSummary(String areaCode);

    Map<String, Object> cntTotalDevice(String areaCode);
}
