package com.ruoyi.ems.service.impl;

import com.huashe.common.utils.DateUtils;
import com.ruoyi.ems.domain.ElecMeterH;
import com.ruoyi.ems.domain.EnergyMeter;
import com.ruoyi.ems.mapper.ElecMeterHMapper;
import com.ruoyi.ems.model.QueryMeter;
import com.ruoyi.ems.service.IElecMeterHService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 用电计量-小时Service业务层处理
 *
 * @author ruoyi
 * @date 2024-12-03
 */
@Service
public class ElecMeterHServiceImpl implements IElecMeterHService {
    @Autowired
    private ElecMeterHMapper elecMeterHMapper;

    /**
     * 根据电表/断路器查询用电计量-小时列表
     *
     * @param queryMeter 用电计量-小时
     * @return 用电计量-小时
     */
    @Override
    public List<ElecMeterH> selectByMeterDev(QueryMeter queryMeter) {
        return elecMeterHMapper.selectElecMeterByDev(queryMeter);
    }

    /**
     * 根据多个电表/断路器合并查询用电计量-小时列表
     *
     * @param queryMeter 用电计量-小时
     * @return 用电计量-小时
     */
    @Override
    public List<ElecMeterH> selectByMeterDevs(QueryMeter queryMeter) {
        return elecMeterHMapper.selectElecMeterByDevs(queryMeter);
    }

    @Override
    public List<ElecMeterH> staMeterDayList(QueryMeter queryMeter) {
        return elecMeterHMapper.selectElecMeterDayList(queryMeter);
    }

    @Override
    public List<EnergyMeter> staByTime(QueryMeter queryMeter) {
        return elecMeterHMapper.selectStaByTime(queryMeter);
    }

    /**
     * 统计用电计量-根据边界对象
     *
     * @param queryMeter 查询条件
     * @return 统计电量信息
     */
    @Override
    public EnergyMeter staByMeterDev(QueryMeter queryMeter) {
        return elecMeterHMapper.selectElecMeterSumByDev(queryMeter);
    }

    @Override
    public EnergyMeter selectElecDayAvg(QueryMeter queryMeter) {
        return elecMeterHMapper.selectElecDayAvg(queryMeter);
    }

    @Override
    public ElecMeterH selectLatelyItem(String deviceCode) {
        return elecMeterHMapper.selectLatelyItem(deviceCode);
    }

    /**
     * 新增用电计量-小时
     *
     * @param elecMeterH 用电计量-小时
     * @return 结果
     */
    @Override
    public int insertElecMeterH(ElecMeterH elecMeterH) {
        return elecMeterHMapper.insertElecMeterH(elecMeterH);
    }

    @Override
    public int insertBatch(List<ElecMeterH> list) {
        return elecMeterHMapper.insertBatch(list);
    }

    /**
     * 修改用电计量-小时
     *
     * @param elecMeterH 用电计量-小时
     * @return 结果
     */
    @Override
    public int updateElecMeterH(ElecMeterH elecMeterH) {
        return elecMeterHMapper.updateElecMeterH(elecMeterH);
    }

    /**
     * 删除用电计量-小时信息
     *
     * @param date 日期
     * @return 结果
     */
    @Override
    public int deleteElecMeterHByDate(String date) {
        return elecMeterHMapper.deleteElecMeterHByDate(date);
    }

    @Override
    public EnergyMeter qryElecMeterByDate(String date, String areaCode) {
        return elecMeterHMapper.qryElecMeterByDate(new ElecMeterH() {{
            setStartRecTime(date);
            setAreaCode(areaCode);
        }});
    }

    @Override
    public List<ElecMeterH> qryTimeIndexElecMeterByDay(String dateRange, Integer timeIndex) {
        return elecMeterHMapper.qryTimeIndexElecMeterByDay(dateRange);
    }

    @Override
    public List<ElecMeterH> qryDateElecMeterByDate(String dateRange) {
        return elecMeterHMapper.qryDateElecMeterByDate(dateRange);
    }

    @Override
    public List<ElecMeterH> qryDateElecMeterByYear(String dataRange) {
        return elecMeterHMapper.qryDateElecMeterByYear(dataRange);
    }

    @Override
    public List<ElecMeterH> qryDeviceTypeElecMeterByDay(ElecMeterH elecMeterH) {
        return elecMeterHMapper.qryDeviceTypeElecMeterByDay(elecMeterH);
    }

}
