package com.ruoyi.ems.service.impl;

import cn.hutool.core.thread.ThreadUtil;
import com.ruoyi.common.core.utils.DateTimeUtil;
import com.ruoyi.ems.domain.ElecPvSupplyH;
import com.ruoyi.ems.mapper.ElecPvSupplyHMapper;
import com.ruoyi.ems.model.QueryMeter;
import com.ruoyi.ems.service.IElecPvSupplyHService;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.Future;

/**
 * 光伏并网计量光伏并网计量-小时Service业务层处理
 *
 * @author ruoyi
 * @date 2024-08-02
 */
@Slf4j
@Service
public class ElecPvSupplyHServiceImpl implements IElecPvSupplyHService {
    @Autowired
    private ElecPvSupplyHMapper pvSupplyHMapper;

    /**
     * 查询光伏并网计量光伏并网计量-小时
     *
     * @param id 光伏并网计量光伏并网计量-小时主键
     * @return 光伏并网计量光伏并网计量-小时
     */
    @Override
    public ElecPvSupplyH selectPvSupplyHById(Long id) {
        return pvSupplyHMapper.selectPvSupplyHById(id);
    }

    /**
     * 查询光伏并网计量光伏并网计量-小时列表
     *
     * @param pvSupplyH 光伏并网计量光伏并网计量-小时
     * @return 光伏并网计量光伏并网计量-小时
     */
    @Override
    public List<ElecPvSupplyH> selectPvSupplyHList(ElecPvSupplyH pvSupplyH) {
        if (StringUtils.equals("-1", pvSupplyH.getAreaCode())) {
            return pvSupplyHMapper.selectPvSupplyHAll(pvSupplyH);
        }
        else {
            return pvSupplyHMapper.selectPvSupplyHList(pvSupplyH);
        }
    }

    @Override
    public List<ElecPvSupplyH> selectPvSupplyDayList(QueryMeter param) {
        return pvSupplyHMapper.selectPvSupplyDayList(param);
    }

    /**
     * 新增光伏并网计量光伏并网计量-小时
     *
     * @param pvSupplyH 光伏并网计量光伏并网计量-小时
     * @return 结果
     */
    @Override
    public int insertPvSupplyH(ElecPvSupplyH pvSupplyH) {
        return pvSupplyHMapper.insertPvSupplyH(pvSupplyH);
    }

    /**
     * 修改光伏并网计量光伏并网计量-小时
     *
     * @param pvSupplyH 光伏并网计量光伏并网计量-小时
     * @return 结果
     */
    @Override
    public int updatePvSupplyH(ElecPvSupplyH pvSupplyH) {
        return pvSupplyHMapper.updatePvSupplyH(pvSupplyH);
    }

    /**
     * 批量删除光伏并网计量光伏并网计量-小时
     *
     * @param ids 需要删除的光伏并网计量光伏并网计量-小时主键
     * @return 结果
     */
    @Override
    public int deletePvSupplyHByIds(Long[] ids) {
        return pvSupplyHMapper.deletePvSupplyHByIds(ids);
    }

    /**
     * 删除光伏并网计量光伏并网计量-小时信息
     *
     * @param id 光伏并网计量光伏并网计量-小时主键
     * @return 结果
     */
    @Override
    public int deletePvSupplyHById(Long id) {
        return pvSupplyHMapper.deletePvSupplyHById(id);
    }



    @Override
    public Map<String, ElecPvSupplyH> calPvByDateRange(QueryMeter param) {
        Future<?> thisDay = ThreadUtil.execAsync(() -> pvSupplyHMapper.calPvByDateRange(new QueryMeter() {{
            setDate(DateTimeUtil.currentDateTime(DateTimeUtil.DateFormatter.yyyy_MM_dd));
            setAreaCode(param.getAreaCode());
        }}));
        Future<?> thisMonth = ThreadUtil.execAsync(() -> pvSupplyHMapper.calPvByDateRange(new QueryMeter() {
            {
                setDate(DateTimeUtil.currentDateTime(DateTimeUtil.DateFormatter.yyyy_MM));
                setAreaCode(param.getAreaCode());
            }
        }));
        Future<?> thisYear = ThreadUtil.execAsync(() -> pvSupplyHMapper.calPvByDateRange(new QueryMeter() {{
            setAreaCode(param.getAreaCode());
            setDate(DateTimeUtil.currentDateTime(DateTimeUtil.DateFormatter.yyyy));
        }}));
        Future<?> total = ThreadUtil.execAsync(() -> pvSupplyHMapper.calPvByDateRange(new QueryMeter() {{
            setAreaCode(param.getAreaCode());
        }}));
        Map<String, ElecPvSupplyH> result = new HashMap<>();
        try {
            result.put("thisDay", (ElecPvSupplyH) thisDay.get());
            result.put("thisMonth", (ElecPvSupplyH) thisMonth.get());
            result.put("thisYear", (ElecPvSupplyH) thisYear.get());
            result.put("total", (ElecPvSupplyH) total.get());
        } catch (Exception e) {
            log.error("calPvByDateRange error {}", e.getMessage());
        }
        return result;
    }

    @Override
    public List<ElecPvSupplyH> calDayPvRange(QueryMeter param) {
        return pvSupplyHMapper.calDayPvRange(param);
    }

    @Override
    public List<ElecPvSupplyH> calHourPvRange(QueryMeter param) {
        return pvSupplyHMapper.calHourPvRange(param);
    }

    @Override
    public List<ElecPvSupplyH> calMonthPvByDateRange(QueryMeter param) {
        return pvSupplyHMapper.calMonthPvByDateRange(param);
    }
}
