package com.ruoyi.ems.service.impl;

import com.ruoyi.ems.domain.EmsTag;
import com.ruoyi.ems.mapper.EmsTagMapper;
import com.ruoyi.ems.service.IEmsTagService;
import com.ruoyi.ems.service.IObjTagRelService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 标签分类Service业务层处理
 *
 * @author ruoyi
 * @date 2024-07-31
 */
@Service
public class EmsTagServiceImpl implements IEmsTagService {
    @Autowired
    private EmsTagMapper emsTagMapper;

    @Autowired
    private IObjTagRelService tagRelService;

    /**
     * 查询标签分类
     *
     * @param id 标签分类主键
     * @return 标签分类
     */
    @Override
    public EmsTag selectEmsTagById(Long id) {
        return emsTagMapper.selectEmsTagById(id);
    }

    /**
     * 查询标签分类列表
     *
     * @param emsTag 标签分类
     * @return 标签分类
     */
    @Override
    public List<EmsTag> selectEmsTagList(EmsTag emsTag) {
        return emsTagMapper.selectEmsTagList(emsTag);
    }

    /**
     * 新增标签分类
     *
     * @param emsTag 标签分类
     * @return 结果
     */
    @Override
    public int insertEmsTag(EmsTag emsTag) {
        return emsTagMapper.insertEmsTag(emsTag);
    }

    /**
     * 修改标签分类
     *
     * @param emsTag 标签分类
     * @return 结果
     */
    @Override
    public int updateEmsTag(EmsTag emsTag) {
        return emsTagMapper.updateEmsTag(emsTag);
    }

    /**
     * 批量删除标签分类
     *
     * @param ids 需要删除的标签分类主键
     * @return 结果
     */
    @Override
    public int deleteEmsTagByIds(Long[] ids) {
        for (Long id : ids) {
            EmsTag tag = emsTagMapper.selectEmsTagById(id);
            if (null != tag) {
                tagRelService.deleteByTagCode(tag.getTagCode());
            }
        }

        return emsTagMapper.deleteEmsTagByIds(ids);
    }

    /**
     * 删除标签分类信息
     *
     * @param id 标签分类主键
     * @return 结果
     */
    @Override
    public int deleteEmsTagById(Long id) {
        EmsTag tag = emsTagMapper.selectEmsTagById(id);

        if (null != tag) {
            tagRelService.deleteByTagCode(tag.getTagCode());
        }

        return emsTagMapper.deleteEmsTagById(id);
    }
}
